/*
 * Translatable strings file generated by Glade.
 * Add this file to your project's POTFILES.in.
 * DO NOT compile it as part of your application.
 */

gchar *s = N_("Openbox Configuration Manager");
gchar *s = N_("<span weight=\"bold\">Theme</span>");
gchar *s = N_("    ");
gchar *s = N_("_Install a new theme...");
gchar *s = N_("Create a theme _archive (.obt)...");
gchar *s = N_("Theme");
gchar *s = N_("<span weight=\"bold\">Windows</span>");
gchar *s = N_("    ");
gchar *s = N_("_Windows retain a border when undecorated");
gchar *s = N_("A_nimate iconify and restore");
gchar *s = N_("<span weight=\"bold\">Window Titles</span>");
gchar *s = N_("    ");
gchar *s = N_("_Button order:");
gchar *s = N_("N - The window's icon\n"
              "D - The all-desktops (sticky) button\n"
              "S - The shade (roll up) button\n"
              "L - The label (window title)\n"
              "I - The iconify (minimize) button\n"
              "M - The maximize button\n"
              "C - The close button");
gchar *s = N_("    ");
gchar *s = N_("N:\n"
              "L:\n"
              "I:\n"
              "M:");
gchar *s = N_("Window icon\n"
              "Window label (Title)\n"
              "Iconify (Minimize)\n"
              "Maximize");
gchar *s = N_("C:\n"
              "S:\n"
              "D:");
gchar *s = N_("Close\n"
              "Shade (Roll up)\n"
              "Omnipresent (On all desktops)");
gchar *s = N_("<span weight=\"bold\">Fonts</span>");
gchar *s = N_("    ");
gchar *s = N_("_Active window title: ");
gchar *s = N_("_Inactive window title: ");
gchar *s = N_("Menu _header: ");
gchar *s = N_("_Menu Item: ");
gchar *s = N_("Active _On-screen display: ");
gchar *s = N_("Inactive O_n-screen display: ");
gchar *s = N_("Appearance");
gchar *s = N_("<span weight=\"bold\">Focusing Windows</span>");
gchar *s = N_("    ");
gchar *s = N_("Focus _new windows when they appear");
gchar *s = N_("<span weight=\"bold\">Placing Windows</span>");
gchar *s = N_("    ");
gchar *s = N_("_Place new windows under the mouse pointer");
gchar *s = N_("_Center new windows when they are placed");
gchar *s = N_("Prefer to place new windows _on:");
gchar *s = N_("All monitors");
gchar *s = N_("The active monitor");
gchar *s = N_("The monitor with the mouse");
gchar *s = N_("<span weight=\"bold\">Primary Monitor</span>");
gchar *s = N_("    ");
gchar *s = N_("The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.");
gchar *s = N_("Primary _monitor:");
gchar *s = N_("Fixed Monitor");
gchar *s = N_("Active Monitor");
gchar *s = N_("Monitor With Mouse Pointer");
gchar *s = N_("    ");
gchar *s = N_("_Fixed monitor:");
gchar *s = N_("Windows");
gchar *s = N_("<span weight=\"bold\">Moving and Resizing Windows</span>");
gchar *s = N_("    ");
gchar *s = N_("Update the window contents while _resizing");
gchar *s = N_("Drag _threshold distance:");
gchar *s = N_("px");
gchar *s = N_("Amount of resistance against other _windows:");
gchar *s = N_("px");
gchar *s = N_("Amount of resistance against screen _edges:");
gchar *s = N_("px");
gchar *s = N_("_Switch desktops when moving a window past the screen edge");
gchar *s = N_("    ");
gchar *s = N_("_Amount of time to wait before switching:");
gchar *s = N_("ms");
gchar *s = N_("<span weight=\"bold\">Information Dialog</span>");
gchar *s = N_("Show _information dialog:");
gchar *s = N_("When resizing terminal windows");
gchar *s = N_("Always");
gchar *s = N_("Never");
gchar *s = N_("    ");
gchar *s = N_("Information dialog's _position:");
gchar *s = N_("Centered on the window");
gchar *s = N_("Above the window");
gchar *s = N_("Fixed position on screen");
gchar *s = N_("    ");
gchar *s = N_("Fixed _x position:");
gchar *s = N_("Centered");
gchar *s = N_("From left edge");
gchar *s = N_("From right edge");
gchar *s = N_("px");
gchar *s = N_("Fixed _y position:");
gchar *s = N_("Centered");
gchar *s = N_("From top edge");
gchar *s = N_("From bottom edge");
gchar *s = N_("px");
gchar *s = N_("Move & Resize");
gchar *s = N_("<span weight=\"bold\">Focusing Windows</span>");
gchar *s = N_("    ");
gchar *s = N_("_Focus windows when the mouse pointer moves over them");
gchar *s = N_("    ");
gchar *s = N_("Move focus under the mouse when _switching desktops");
gchar *s = N_("Move focus _under the mouse when the mouse is not moving");
gchar *s = N_("_Raise windows when the mouse pointer moves over them");
gchar *s = N_("_Delay before focusing and raising windows:");
gchar *s = N_("ms");
gchar *s = N_("<span weight=\"bold\">Titlebar</span>");
gchar *s = N_("    ");
gchar *s = N_("Double click on the _titlebar:");
gchar *s = N_("Maximizes the window");
gchar *s = N_("Shades the window");
gchar *s = N_("Double click ti_me:");
gchar *s = N_("ms");
gchar *s = N_("    ");
gchar *s = N_("Mouse");
gchar *s = N_("<span weight=\"bold\">Desktops</span>");
gchar *s = N_("    ");
gchar *s = N_("_Show a notification when switching desktops");
gchar *s = N_("    ");
gchar *s = N_("_Amount of time to show the notification for:");
gchar *s = N_("ms");
gchar *s = N_("_Number of desktops: ");
gchar *s = N_("_Desktop names:");
gchar *s = N_("Desktops");
gchar *s = N_("<span weight=\"bold\">Desktop Margins</span>");
gchar *s = N_("    ");
gchar *s = N_("Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.");
gchar *s = N_("_Top");
gchar *s = N_("px");
gchar *s = N_("_Left");
gchar *s = N_("px");
gchar *s = N_("_Right");
gchar *s = N_("px");
gchar *s = N_("_Bottom");
gchar *s = N_("px");
gchar *s = N_("Margins");
gchar *s = N_("<span weight=\"bold\">Dock</span>");
gchar *s = N_("    ");
gchar *s = N_("The dock is a special container for \"dockapps\", or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.");
gchar *s = N_("<span weight=\"bold\">Position</span>");
gchar *s = N_("    ");
gchar *s = N_("_Position:");
gchar *s = N_("Top Left");
gchar *s = N_("Top");
gchar *s = N_("Top Right");
gchar *s = N_("Left");
gchar *s = N_("Right");
gchar *s = N_("Bottom Left");
gchar *s = N_("Bottom");
gchar *s = N_("Bottom Right");
gchar *s = N_("Floating");
gchar *s = N_("    ");
gchar *s = N_("_Floating position:");
gchar *s = N_("x");
gchar *s = N_("    ");
gchar *s = N_("Allow _windows to be placed within the dock's area");
gchar *s = N_("_Orientation: ");
gchar *s = N_("Vertical");
gchar *s = N_("Horizontal");
gchar *s = N_("<span weight=\"bold\">Stacking</span>");
gchar *s = N_("    ");
gchar *s = N_("Keep dock _above other windows");
gchar *s = N_("A_llow dock to be both above and below windows");
gchar *s = N_("Keep dock _below other windows");
gchar *s = N_("<span weight=\"bold\">Hiding</span>");
gchar *s = N_("    ");
gchar *s = N_("_Hide off screen");
gchar *s = N_("    ");
gchar *s = N_("_Delay before hiding:");
gchar *s = N_("ms");
gchar *s = N_("    ");
gchar *s = N_("Delay before _showing:");
gchar *s = N_("ms");
gchar *s = N_("Dock");
gchar *s = N_("Abo_ut");
gchar *s = N_("About ObConf");
gchar *s = N_("<span weight=\"bold\" size=\"xx-large\">ObConf VERSION</span>");
gchar *s = N_("A preferences manager for Openbox");
gchar *s = N_("Copyright (c) 2003-2008\n"
              "Dana Jansens <danakj@orodu.net>\n"
              "Tim Riley <tr@slackzone.org>\n"
              "Javeed Shaikh <syscrash2k@gmail.com>");
gchar *s = N_("window1");
gchar *s = N_("<span weight=\"bold\">Press the key you wish to bind...</span>");
